@@ -191,7 +191,7 @@ bool AlbumIconViewFilter::eventFilter(TQObject *object, TQEvent *e)
     if (e->type() == TQEvent::MouseButtonRelease)
     {
         TQMouseEvent* event = TQT_TQMOUSEEVENT(e);
-        if ( TQT_TQRECT_OBJECT(widget->rect()).contains(event->pos()) && d->led->ledColor() != StatusLed::Gray)
+        if ( widget->rect().contains(event->pos()) && d->led->ledColor() != StatusLed::Gray)
         {
             // Reset all filters settings.
             d->textFilter->setText(TQString());
