@@ -1505,7 +1505,7 @@ void DigikamApp::slotDownloadImages()
 
 void DigikamApp::slotCameraConnect()
 {
-    CameraType* ctype = d->cameraList->find(TQString::fromUtf8(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name()));
+    CameraType* ctype = d->cameraList->find(TQString::fromUtf8(sender()->name()));
 
     if (ctype)
     {
