@@ -138,7 +138,7 @@ IconView::IconView(TQWidget* parent, const char* name)
 {
     viewport()->setBackgroundMode(TQt::NoBackground);
     viewport()->setFocusProxy(this);
-    viewport()->setFocusPolicy(TQ_WheelFocus);
+    viewport()->setFocusPolicy(TQWidget::WheelFocus);
     viewport()->setMouseTracking(true);
 
     d = new IconViewPriv;
