@@ -33,15 +33,15 @@
 
 // KDE includes.
 
-#include <kabc/stdaddressbook.h>
-#include <kpopupmenu.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeabc/stdaddressbook.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kcursor.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 // Local includes.
 
@@ -330,7 +330,7 @@ TagFilterView::TagFilterView(TQWidget* parent)
 
     // ------------------------------------------------------------------------
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("Tag Filters View");
     d->matchingCond = (AlbumLister::MatchingCondition)(config->readNumEntry("Matching Condition",
                                                        AlbumLister::OrCondition));
@@ -340,7 +340,7 @@ TagFilterView::TagFilterView(TQWidget* parent)
 
 TagFilterView::~TagFilterView()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("Tag Filters View");
     config->writeEntry("Matching Condition", (int)(d->matchingCond));
     config->writeEntry("Toggle Auto Tags", (int)(d->toggleAutoTags));
@@ -553,7 +553,7 @@ void TagFilterView::contentsDropEvent(TQDropEvent *e)
         if (talbum == itemDrop->album())
             return;
 
-        KPopupMenu popMenu(this);
+        TDEPopupMenu popMenu(this);
         popMenu.insertTitle(SmallIcon("digikam"), i18n("Tag Filters"));
         popMenu.insertItem(SmallIcon("goto"), i18n("&Move Here"), 10);
         popMenu.insertSeparator(-1);
@@ -620,7 +620,7 @@ void TagFilterView::contentsDropEvent(TQDropEvent *e)
         }
         else
         {
-            KPopupMenu popMenu(this);
+            TDEPopupMenu popMenu(this);
             popMenu.insertTitle(SmallIcon("digikam"), i18n("Tag Filters"));
             popMenu.insertItem(SmallIcon("tag"), i18n("Assign Tag '%1' to Items")
                                 .arg(destAlbum->prettyURL()), 10) ;
@@ -876,7 +876,7 @@ void TagFilterView::slotContextMenu(TQListViewItem* it, const TQPoint&, int)
     connect(d->ABCMenu, TQT_SIGNAL( aboutToShow() ),
             this, TQT_SLOT( slotABCContextMenu() ));
 
-    KPopupMenu popmenu(this);
+    TDEPopupMenu popmenu(this);
     popmenu.insertTitle(SmallIcon("digikam"), i18n("Tag Filters"));
     popmenu.insertItem(SmallIcon("tag-new"), i18n("New Tag..."), 10);
     popmenu.insertItem(SmallIcon("tag-addressbook"), i18n("Create Tag From AddressBook"), d->ABCMenu);
@@ -1097,9 +1097,9 @@ void TagFilterView::slotABCContextMenu()
     d->ABCMenu->clear();
 
     int counter = 100;
-    KABC::AddressBook* ab = KABC::StdAddressBook::self();
+    TDEABC::AddressBook* ab = TDEABC::StdAddressBook::self();
     TQStringList names;
-    for ( KABC::AddressBook::Iterator it = ab->begin(); it != ab->end(); ++it )
+    for ( TDEABC::AddressBook::Iterator it = ab->begin(); it != ab->end(); ++it )
     {
         names.push_back(it->formattedName());
     }
@@ -1246,7 +1246,7 @@ void TagFilterView::tagDelete(TagFilterViewItem* item)
     int result = KMessageBox::warningContinueCancel(0, message,
                                                     i18n("Delete Tag"),
                                                     KGuiItem(i18n("Delete"),
-                                                    "editdelete"));
+                                                    "edit-delete"));
 
     if (result == KMessageBox::Continue)
     {
@@ -1359,7 +1359,7 @@ void TagFilterView::slotResetTagFilters()
 
 void TagFilterView::loadViewState()
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(name());
 
     int selectedItem = config->readNumEntry("LastSelectedItem", 0);
@@ -1406,7 +1406,7 @@ void TagFilterView::loadViewState()
 
 void TagFilterView::saveViewState()
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(name());
 
     TagFilterViewItem *item = dynamic_cast<TagFilterViewItem*>(selectedItem());
