@@ -37,16 +37,16 @@
 
 // KDE includes.
 
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kdialog.h>
 #include <klineedit.h>
 #include <kiconloader.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <ksqueezedtextlabel.h>
 #include <kstandarddirs.h>
-#include <kdeversion.h>
-#include <kmessagebox.h>
+#include <tdeversion.h>
+#include <tdemessagebox.h>
 
 #if KDE_IS_VERSION(3,2,0)
 #include <kinputdialog.h>
@@ -138,7 +138,7 @@ TimeLineView::TimeLineView(TQWidget *parent)
     d->timeUnitCB->insertItem(i18n("Month"), TimeLineWidget::Month);
     d->timeUnitCB->insertItem(i18n("Year"),  TimeLineWidget::Year);
     d->timeUnitCB->setCurrentItem((int)TimeLineWidget::Month);
-    d->timeUnitCB->setFocusPolicy(TQ_NoFocus);
+    d->timeUnitCB->setFocusPolicy(TQWidget::NoFocus);
     TQWhatsThis::add(d->timeUnitCB, i18n("<p>Select the histogram time unit here.<p>"
                                         "You can change the graph decade to zoom in or zoom out over time."));
 
@@ -155,16 +155,16 @@ TimeLineView::TimeLineView(TQWidget *parent)
     TQPushButton *linHistoButton = new TQPushButton( d->scaleBG );
     TQToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     d->scaleBG->insert(linHistoButton, TimeLineWidget::LinScale);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( TQPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton( d->scaleBG );
     TQToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     d->scaleBG->insert(logHistoButton, TimeLineWidget::LogScale);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( TQPixmap( directory + "histogram-log.png" ) );
     logHistoButton->setToggleButton(true);
 
@@ -204,7 +204,7 @@ TimeLineView::TimeLineView(TQWidget *parent)
                                       "\"My Date Searches\" view"));
 
     d->saveButton  = new TQPushButton(hbox2);
-    d->saveButton->setPixmap(SmallIcon("filesave"));
+    d->saveButton->setPixmap(SmallIcon("document-save"));
     d->saveButton->setEnabled(false);
     TQToolTip::add(d->saveButton, i18n("Save current selection to a new virtual Album"));
     TQWhatsThis::add(d->saveButton, i18n("<p>If you press this button, current "
@@ -311,7 +311,7 @@ SearchTextBar* TimeLineView::searchBar() const
 void TimeLineView::slotInit()
 {
     // Date Maps are loaded from AlbumManager to TimeLineWidget after than GUI is initialized.
-    // AlbumManager query Date KIO slave to stats items from database and it can take a while.
+    // AlbumManager query Date TDEIO slave to stats items from database and it can take a while.
     // We waiting than TimeLineWidget is ready before to set last config from users.
 
     readConfig();
@@ -325,7 +325,7 @@ void TimeLineView::slotInit()
 
 void TimeLineView::readConfig()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("TimeLine SideBar");
 
     d->timeUnitCB->setCurrentItem(config->readNumEntry("Histogram TimeUnit", TimeLineWidget::Month));
@@ -341,7 +341,7 @@ void TimeLineView::readConfig()
 
 void TimeLineView::writeConfig()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("TimeLine SideBar");
     config->writeEntry("Histogram TimeUnit", d->timeUnitCB->currentItem());
     config->writeEntry("Histogram Scale", d->scaleBG->selectedId());
@@ -443,7 +443,7 @@ void TimeLineView::createNewDateSearchAlbum(const TQString& name)
     d->timeLineFolderView->clearSelection();
     d->timeLineFolderView->blockSignals(false);
 
-    // We will make now the Url for digiKam Search KIO-Slave
+    // We will make now the Url for digiKam Search TDEIO-Slave
 
     KURL url;
     url.setProtocol("digikamsearch");
@@ -494,7 +494,7 @@ void TimeLineView::slotAlbumSelected(SAlbum* salbum)
         return;
     }
 
-    // Date Search url for KIO-Slave is something like that :
+    // Date Search url for TDEIO-Slave is something like that :
     // digikamsearch:1 AND 2 OR 3 AND 4 OR 5 AND 6?
     //               1.key=imagedate&1.op=GT&1.val=2006-02-06&
     //               2.key=imagedate&2.op=LT&2.val=2006-02-07&
