@@ -42,7 +42,7 @@ namespace Digikam
 
 class DIGIKAM_EXPORT WelcomePageView : public TDEHTMLPart
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
 
