@@ -51,7 +51,7 @@ namespace DigikamImagesPluginCore
 
 class AutoCorrectionTool : public Digikam::EditorTool
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
