@@ -41,13 +41,13 @@
 
 // KDE includes.
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kcolordialog.h>
 #include <kcolordialog.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 
 // Digikam includes.
@@ -125,16 +125,16 @@ RedEyeTool::RedEyeTool(TQObject* parent)
     TQPushButton *linHistoButton = new TQPushButton(m_scaleBG);
     TQToolTip::add(linHistoButton, i18n("<p>Linear"));
     m_scaleBG->insert(linHistoButton, HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap(TQPixmap(directory + "histogram-lin.png"));
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton(m_scaleBG);
     TQToolTip::add(logHistoButton, i18n("<p>Logarithmic"));
     m_scaleBG->insert(logHistoButton, HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap(TQPixmap(directory + "histogram-log.png"));
     logHistoButton->setToggleButton(true);
 
@@ -294,7 +294,7 @@ void RedEyeTool::slotColorSelectedFromTarget(const DColor& color)
 
 void RedEyeTool::readSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("redeye Tool");
     m_channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", 0)); // Luminosity.
     m_scaleBG->setButton(config->readNumEntry("Histogram Scale", HistogramWidget::LogScaleHistogram));
@@ -313,7 +313,7 @@ void RedEyeTool::readSettings()
 
 void RedEyeTool::writeSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("redeye Tool");
     config->writeEntry("Histogram Channel", m_channelCB->currentItem());
     config->writeEntry("Histogram Scale", m_scaleBG->selectedId());
