@@ -48,7 +48,7 @@ class DImgThreadedFilter;
 
 class DIGIKAM_EXPORT CtrlPanelDlg : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
