@@ -35,11 +35,11 @@
 
 // KDE includes.
 
-#include <klocale.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kdialogbase.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
 #include <kmimetype.h>
 #include <kseparator.h>
 #include <ksqueezedtextlabel.h>
@@ -397,10 +397,10 @@ void CameraItemPropertiesTab::setCurrentItem(const GPItemInfo* itemInfo,
 
     TQDateTime date;
     date.setTime_t(itemInfo->mtime);
-    d->labelFileDate->setText(KGlobal::locale()->formatDateTime(date, true, true));
+    d->labelFileDate->setText(TDEGlobal::locale()->formatDateTime(date, true, true));
 
-    str = i18n("%1 (%2)").arg(KIO::convertSize(itemInfo->size))
-                         .arg(KGlobal::locale()->formatNumber(itemInfo->size, 0));
+    str = i18n("%1 (%2)").arg(TDEIO::convertSize(itemInfo->size))
+                         .arg(TDEGlobal::locale()->formatNumber(itemInfo->size, 0));
     d->labelFileSize->setText(str);
 
     // -- Image Properties --------------------------------------------------
@@ -517,7 +517,7 @@ void CameraItemPropertiesTab::setCurrentItem(const GPItemInfo* itemInfo,
 
     if (photoInfo.dateTime.isValid())
     {
-        str = KGlobal::locale()->formatDateTime(photoInfo.dateTime, true, true);
+        str = TDEGlobal::locale()->formatDateTime(photoInfo.dateTime, true, true);
         d->labelPhotoDateTime->setText(str);
     }
     else
