@@ -502,7 +502,7 @@ void ThumbBarView::viewportPaintEvent(TQPaintEvent* e)
                 {
                     TQPixmap pix; 
                     pix.convertFromImage(TQImage(item->d->pixmap->convertToImage()).
-                                         smoothScale(d->tileSize, d->tileSize, TQ_ScaleMin));
+                                         smoothScale(d->tileSize, d->tileSize, TQImage::ScaleMin));
                     int x = (tile.width()  - pix.width())/2;
                     int y = (tile.height() - pix.height())/2;
                     bitBlt(&tile, x, y, &pix);
@@ -529,7 +529,7 @@ void ThumbBarView::viewportPaintEvent(TQPaintEvent* e)
                 {
                     TQPixmap pix; 
                     pix.convertFromImage(TQImage(item->d->pixmap->convertToImage()).
-                                         smoothScale(d->tileSize, d->tileSize, TQ_ScaleMin));
+                                         smoothScale(d->tileSize, d->tileSize, TQImage::ScaleMin));
                     int x = (tile.width() - pix.width())/2;
                     int y = (tile.height()- pix.height())/2;
                     bitBlt(&tile, x, y, &pix);
