@@ -67,7 +67,7 @@ int DLogoAction::plug(TQWidget *widget, int index)
         TDEGlobal::dirs()->addResourceType("banner-digikam", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
         TQString directory = TDEGlobal::dirs()->findResourceDir("banner-digikam", "banner-digikam.png");
         pixmapLogo->setPixmap(TQPixmap( directory + "banner-digikam.png" ));
-        pixmapLogo->setFocusPolicy(TQ_NoFocus);
+        pixmapLogo->setFocusPolicy(TQWidget::NoFocus);
 
         bar->insertWidget(id, pixmapLogo->width(), pixmapLogo);
         bar->alignItemRight(id);
