@@ -156,7 +156,7 @@ SearchTextBar::SearchTextBar(TQWidget *parent, const char* name, const TQString
              : TQWidget(parent, 0, TQt::WDestructiveClose)
 {
     d = new SearchTextBarPriv;
-    setFocusPolicy(TQ_NoFocus);
+    setFocusPolicy(TQWidget::NoFocus);
     setName(name);
 
     TQHBoxLayout *hlay = new TQHBoxLayout(this);
