@@ -312,7 +312,7 @@ bool Sidebar::eventFilter(TQObject *obj, TQEvent *ev)
 
     for (TQPtrListIterator<KMultiTabBarTab> it(*pTabs); it.current(); ++it)
     {
-        if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(*it) )
+        if ( obj == *it )
         {
             if ( ev->type() == TQEvent::DragEnter)
             {
