@@ -66,30 +66,30 @@ StatusNavigateBar::StatusNavigateBar(TQWidget *parent)
                  : TQWidget(parent, 0, TQt::WDestructiveClose)
 {
     d = new StatusNavigateBarPriv;
-    setFocusPolicy(TQ_NoFocus);
+    setFocusPolicy(TQWidget::NoFocus);
 
     TQHBoxLayout *lay = new TQHBoxLayout(this);
 
     d->firstButton = new TQToolButton(this);
-    d->firstButton->setFocusPolicy(TQ_NoFocus);
+    d->firstButton->setFocusPolicy(TQWidget::NoFocus);
     d->firstButton->setAutoRaise(true);
     d->firstButton->setIconSet(SmallIconSet("go-first"));
     TQToolTip::add(d->firstButton, i18n("Go to the first item"));
 
     d->prevButton = new TQToolButton(this);
-    d->prevButton->setFocusPolicy(TQ_NoFocus);
+    d->prevButton->setFocusPolicy(TQWidget::NoFocus);
     d->prevButton->setAutoRaise(true);
     d->prevButton->setIconSet(SmallIconSet("back"));
     TQToolTip::add(d->prevButton, i18n("Go to the previous item"));
 
     d->nextButton = new TQToolButton(this);
-    d->nextButton->setFocusPolicy(TQ_NoFocus);
+    d->nextButton->setFocusPolicy(TQWidget::NoFocus);
     d->nextButton->setAutoRaise(true);
     d->nextButton->setIconSet(SmallIconSet("forward"));
     TQToolTip::add(d->nextButton, i18n("Go to the next item"));
 
     d->lastButton = new TQToolButton(this);
-    d->lastButton->setFocusPolicy(TQ_NoFocus);
+    d->lastButton->setFocusPolicy(TQWidget::NoFocus);
     d->lastButton->setAutoRaise(true);
     d->lastButton->setIconSet(SmallIconSet("go-last"));
     TQToolTip::add(d->lastButton, i18n("Go to the last item"));
