@@ -77,7 +77,7 @@ StatusProgressBar::StatusProgressBar(TQWidget *parent)
                  : TQWidgetStack(parent, 0, TQt::WDestructiveClose)
 {
     d = new StatusProgressBarPriv;
-    setFocusPolicy(TQ_NoFocus);
+    setFocusPolicy(TQWidget::NoFocus);
 
     d->textLabel      = new KSqueezedTextLabel(this);
     d->progressWidget = new TQWidget(this);
@@ -85,7 +85,7 @@ StatusProgressBar::StatusProgressBar(TQWidget *parent)
     d->progressBar    = new KProgress(d->progressWidget);
     setProgressTotalSteps(100);
     d->cancelButton = new TQPushButton(d->progressWidget);
-    d->cancelButton->setFocusPolicy(TQ_NoFocus);
+    d->cancelButton->setFocusPolicy(TQWidget::NoFocus);
     d->cancelButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
     d->cancelButton->setPixmap(SmallIcon("cancel"));
 
