@@ -674,7 +674,7 @@ void ShowFoto::slotChangeBCG()
 {
     TQString name;
     if (sender())
-        name = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name();
+        name = sender()->name();
 
     if (name == "gamma_plus")
     {
