@@ -375,7 +375,7 @@ CameraUI::CameraUI(TQWidget* /*parent*/, const TQString& cameraTitle,
     TDEGlobal::dirs()->addResourceType("logo-digikam", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
     TQString directory = TDEGlobal::dirs()->findResourceDir("logo-digikam", "logo-digikam.png");
     pixmapLogo->setPixmap( TQPixmap( directory + "logo-digikam.png" ) );
-    pixmapLogo->setFocusPolicy(TQ_NoFocus);
+    pixmapLogo->setFocusPolicy(TQWidget::NoFocus);
 
     d->anim = new AnimWidget(frame, pixmapLogo->height()-2);
 
