@@ -342,7 +342,7 @@ RawSettingsBox::RawSettingsBox(const KURL& url, TQWidget *parent)
     d->resetCurveBtn = new TQToolButton(d->curveBox);
     d->resetCurveBtn->setFixedSize(11, 11);
     d->resetCurveBtn->setIconSet(SmallIconSet("reload_page", 8));
-    d->resetCurveBtn->setFocusPolicy(TQ_NoFocus);
+    d->resetCurveBtn->setFocusPolicy(TQWidget::NoFocus);
     d->resetCurveBtn->setAutoRaise(true);
     TQToolTip::add(d->resetCurveBtn, i18n("Reset curve to linear"));
 
