@@ -403,7 +403,7 @@ void ImageResize::slotValuesChanged()
     d->wpInput->blockSignals(true);
     d->hpInput->blockSignals(true);
 
-    TQString s(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name());
+    TQString s(sender()->name());
 
     if (s == "d->wInput")
     {
